@@ -88,7 +88,7 @@ def copy_files(
         project_src: The name of the project the object is being replicated from.
         runtime: The timestamp to be used in the new replicated metadata.
         client: The client corresponding to the destination project.
-        src_filter: List of files in the destination - Will be used for comparison if current files where not copied by the replicator.
+        src_filter: List of files in the destination - Will be used for comparison if current files were not copied by the replicator.
         jobs: Shared job queue, this is initialized and managed by replication.py.
         exclude_fields: List of fields:  Only support name, description, metadata and metadata.customfield.
     """
@@ -186,9 +186,9 @@ def replicate(
     project_dst = client_dst.config.project
 
     if target_external_ids:
-        files_src = client_src.files.retrieve_multiple(external_ids=target_external_ids, ignore_unknown_ids=True)
+        files_src = client_src.files.retrieve_multiple(external_ids=target_external_ids)
         try:
-            files_dst = client_dst.files.retrieve_multiple(external_ids=target_external_ids, ignore_unknown_ids=True)
+            files_dst = client_dst.files.retrieve_multiple(external_ids=target_external_ids)
         except CogniteNotFoundError:
             files_dst = FileMetadataList([])
     else:
@@ -201,6 +201,12 @@ def replicate(
 
     assets_dst = client_dst.assets.list(limit=None)
     src_dst_ids_assets = replication.existing_mapping(*assets_dst)
+
+    if not src_dst_ids_assets:
+        assets_src = client_src.assets.list(limit=None)
+        src_assets_map = replication.make_external_id_obj_map(assets_src)
+        src_dst_ids_assets = replication.map_ids_from_external_ids(src_assets_map, assets_dst)
+
     logging.info(
         f"If a files asset ids is one of the {len(src_dst_ids_assets)} assets "
         f"that have been replicated then it will be linked."
@@ -210,10 +216,10 @@ def replicate(
     if exclude_pattern:
         compiled_re = re.compile(exclude_pattern)
 
-    def filter_fn(ts):
+    def filter_fn(file):
         if exclude_pattern:
-            return _is_copyable(ts) and compiled_re.search(ts.external_id) is None
-        return _is_copyable(ts)
+            return compiled_re.search(file.external_id) is None
+        return True
 
     if skip_unlinkable or skip_nonasset or exclude_pattern:
         pre_filter_length = len(files_src)
