@@ -106,7 +106,7 @@ def copy_ts(
         project_src: The name of the project the object is being replicated from.
         runtime: The timestamp to be used in the new replicated metadata.
         client: The client corresponding to the destination project.
-        src_filter: List of timeseries in the destination - Will be used for comparison if current timeseries where not copied by the replicator.
+        src_filter: List of timeseries in the destination - Will be used for comparison if current timeseries were not copied by the replicator.
         jobs: Shared job queue, this is initialized and managed by replication.py.
         exclude_fields: List of fields:  Only support name, description, metadata and metadata.customfield.
     """
@@ -216,6 +216,12 @@ def replicate(
 
     assets_dst = client_dst.assets.list(limit=None)
     src_dst_ids_assets = replication.existing_mapping(*assets_dst)
+
+    if not src_dst_ids_assets:
+        assets_src = client_src.assets.list(limit=None)
+        src_assets_map = replication.make_external_id_obj_map(assets_src)
+        src_dst_ids_assets = replication.map_ids_from_external_ids(src_assets_map, assets_dst)
+
     logging.info(
         f"If a time series asset id is one of the {len(src_dst_ids_assets)} assets "
         f"that have been replicated then it will be linked."
@@ -233,7 +239,7 @@ def replicate(
     if skip_unlinkable or skip_nonasset or exclude_pattern:
         pre_filter_length = len(ts_src)
         ts_src = replication.filter_objects(ts_src, src_dst_ids_assets, skip_unlinkable, skip_nonasset, filter_fn)
-        logging.info(f"Filtered out {pre_filter_length - len(ts_src)} events. {len(ts_src)} events remain.")
+        logging.info(f"Filtered out {pre_filter_length - len(ts_src)} time series. {len(ts_src)} time series remain.")
 
     replicated_runtime = int(time.time()) * 1000
     logging.info(f"These copied/updated time series will have a replicated run time of: {replicated_runtime}.")
